@@ -32,7 +32,7 @@ print(
     f"Retrieve raw data in dataset: {raw_dataset.name} - version: {raw_dataset.version}"
 )
 
-raw_dataset.as_mount("/mnt/ged_cni")
+raw_dataset.as_mount("/mnt/input_data")
 
 chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index])
 
